Stan Math Library: stan/math/prim/mat/fun/autocovariance.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
autocovariance.hpp File Reference
`#include <stan/math/prim/mat/fun/autocorrelation.hpp>`
`#include <stan/math/prim/mat/fun/variance.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::autocovariance (const std::vector< T > &y, std::vector< T > &acov, Eigen::FFT< T > &fft)
| Write autocovariance estimates for every lag for the specified input sequence into the specified result using the specified FFT engine. More...
template<typename T >
void | stan::math::autocovariance (const std::vector< T > &y, std::vector< T > &acov)
| Write autocovariance estimates for every lag for the specified input sequence into the specified result. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.